
/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/



void QgsNorthArrowPluginGuiBase::pbnOK_clicked()
{

}


void QgsNorthArrowPluginGuiBase::pbnCancel_clicked()
{

}






void QgsNorthArrowPluginGuiBase::sliderRotation_valueChanged( int )
{

}


void QgsNorthArrowPluginGuiBase::sliderRotation_sliderMoved( int )
{

}


void QgsNorthArrowPluginGuiBase::spinSize_valueChanged( int )
{

}


void QgsNorthArrowPluginGuiBase::cboxShow_toggled( bool )
{

}


void QgsNorthArrowPluginGuiBase::cboPlacement_textChanged( const QString & )
{

}


